/*
  *
  * This file is a part of Libcprime.
  * Library for saving activites and bookmarks, share file and more.
  * Copyright 2019 CuboCore Group
  *
  *
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  *
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  *
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, vsit http://www.gnu.org/licenses/.
  *
  */


#include <QDateTime>
#include <QCollator>

#include "sortfunc.h"


QStringList CPrime::SortFunc::sortDate(const QStringList& dateList, Qt::SortOrder s, const QString& format)
{
	QStringList temp = dateList;

	QList<QDate> dates;

	Q_FOREACH (const QString& str, temp)
	{
		dates.append(QDate::fromString(str, format));
	}

	std::sort(std::begin(dates), std::end(dates));

	switch (s)
	{
	case Qt::AscendingOrder:
		for (int i = 0; i < temp.count(); i++)
		{
			temp.replace(i, dates[i].toString(format));
		}

		break;

	case Qt::DescendingOrder:
	   {
		   int reverse = temp.count() - 1;

		   for (int i = 0; i < temp.count(); i++)
		   {
			   temp.replace(reverse, dates[i].toString(format));
			   reverse--;
		   }

		   break;
	   }
	}

	dates.clear();

	return temp;
}


QStringList CPrime::SortFunc::sortTime(const QStringList& timeList, Qt::SortOrder s, const QString& format)
{
	QStringList temp = timeList;

	QList<QTime> times;

	Q_FOREACH (const QString& str, temp)
	{
		times.append(QTime::fromString(str, format));
	}

	std::sort(std::begin(times), std::end(times));

	switch (s)
	{
	case Qt::AscendingOrder:
		for (int i = 0; i < temp.count(); i++)
		{
			temp.replace(i, times[i].toString(format));
		}

		break;

	case Qt::DescendingOrder:
	   {
		   int reverse = temp.count() - 1;

		   for (int i = 0; i < temp.count(); i++)
		   {
			   temp.replace(reverse, times[i].toString(format));
			   reverse--;
		   }

		   break;
	   }
	}

	times.clear();
	return temp;
}


QStringList CPrime::SortFunc::sortList(const QStringList& list, Qt::SortOrder s)
{
	QStringList temp = list;
	QCollator   sortNum;

	sortNum.setNumericMode(true);

	switch (s)
	{
	case Qt::AscendingOrder:
		std::sort(temp.begin(), temp.end(), sortNum);

		break;

	case Qt::DescendingOrder:
		std::sort(temp.begin(), temp.end(), [&sortNum](const QString& s1, const QString& s2) {
			return sortNum.compare(s1, s2) > 0;
		});

		break;
	}

	return temp;
}


QStringList CPrime::SortFunc::sortDateTime(const QStringList& dateTimeList, Qt::SortOrder s, const QString& format)
{
	QStringList temp = dateTimeList;

	QList<QDateTime> dts;

	Q_FOREACH (const QString& str, temp)
	{
		dts.append(QDateTime::fromString(str, format));
	}

	std::sort(std::begin(dts), std::end(dts));

	switch (s)
	{
	case Qt::AscendingOrder:
		for (int i = 0; i < temp.count(); i++)
		{
			temp.replace(i, dts[i].toString(format));
		}

		break;

	case Qt::DescendingOrder:
	   {
		   int reverse = temp.count() - 1;

		   for (int i = 0; i < temp.count(); i++)
		   {
			   temp.replace(reverse, dts[i].toString(format));
			   reverse--;
		   }

		   break;
	   }
	}

	dts.clear();
	return temp;
}
